@@ -1,4 +1,4 @@
-from typing import Callable, Optional
+from typing import Callable, Optional, Literal
 from enum import Enum
 from kogito.core.head import KnowledgeHeadType
 from kogito.core.utils import vp_present_participle, article, posessive
@@ -511,15 +511,7 @@ PHYSICAL_RELATIONS = [
 ]
 
 #: ATOMIC 2020 Event relations
-EVENT_RELATIONS = [
-    CAUSES,
-    HINDERED_BY,
-    X_REASON,
-    IS_AFTER,
-    IS_BEFORE,
-    HAS_SUB_EVENT,
-    IS_FILLED_BY,
-]
+EVENT_RELATIONS = [CAUSES, HINDERED_BY, X_REASON, IS_AFTER, IS_BEFORE, HAS_SUB_EVENT]
 
 #: ATOMIC 2020 Social relations
 SOCIAL_RELATIONS = [
@@ -560,11 +552,31 @@ CONCEPTNET_TO_ATOMIC_MAP = {
     RECEIVES_ACTION: [MADE_UP_OF, AT_LOCATION, CAUSES, OBJECT_USE],
 }
 
+CUSTOM_RELATIONS = []
+RELATION_KIND = Literal["physical", "event", "social"]
 
-def register_relation(relation: KnowledgeRelation):
+def register_relation(relation: KnowledgeRelation, kind: Optional[RELATION_KIND] = None) -> None:
+    """Register a new relation based on its kind. By default, it registers the relation
+    as a custom relation without a kind, but optionally it can be registered to be a Physical,
+    Event or a Social relation.
+
+    Args:
+        relation (KnowledgeRelation): Knowledge relation to register.
+        kind (Optional[RELATION_KIND], optional): Relation kind. Available kinds: physical, event, social. 
+                                                Defaults to None.
+    """
     if relation not in KG_RELATIONS:
         KG_RELATIONS.append(relation)
 
+        if kind == "physical":
+            PHYSICAL_RELATIONS.append(relation)
+        elif kind == "event":
+            EVENT_RELATIONS.append(relation)
+        elif kind == "social":
+            SOCIAL_RELATIONS.append(relation)
+        else:
+            CUSTOM_RELATIONS.append(relation)
+
 
 RELATION_TO_NL = {
     "AtLocation": "located or found at/in/on",
@@ -601,5 +613,31 @@ RELATION_TO_NL = {
     "xNeed": "but before, PersonX needs",
     "xReact": "as a result, PersonX feels",
     "xReason": "because",
-    "xWant": "as a result, PersonX wants"
-}
\ No newline at end of file
+    "xWant": "as a result, PersonX wants",
+}
+
+RELATION_SIZE = {
+    "ObjectUse": 165590,
+    "AtLocation": 20221,
+    "MadeUpOf": 3345,
+    "HasProperty": 5617,
+    "CapableOf": 7968,
+    "Desires": 2737,
+    "NotDesires": 2838,
+    "isAfter": 22453,
+    "HasSubEvent": 12845,
+    "isBefore": 23208,
+    "HinderedBy": 106658,
+    "Causes": 376,
+    "xReason": 334,
+    "isFilledBy": 33266,
+    "xNeed": 128955,
+    "xAttr": 148194,
+    "xEffect": 115124,
+    "xReact": 81397,
+    "xWant": 135360,
+    "xIntent": 72677,
+    "oEffect": 80166,
+    "oReact": 67236,
+    "oWant": 94548,
+}
