@@ -15,7 +15,7 @@ from torch.utils.data import Sampler
 
 from transformers import BartTokenizer
 
-IGNORE_WORDS = set(["PersonX", "PersonY", "PersonZ", "_", "'", "-"])
+IGNORE_WORDS = set(["personx", "persony", "personz", "_", "'", "-"])
 ROUGE_KEYS = ["rouge1", "rouge2", "rougeL"]
 
 
@@ -209,6 +209,7 @@ def get_uuid(length=8):
         u = u[:length]
     return u
 
+
 def truncate_sequences_dual(sequences, max_length):
     words_to_cut = sum(list(map(len, sequences))) - max_length
     if words_to_cut <= 0:
@@ -230,16 +231,15 @@ def truncate_sequences_dual(sequences, max_length):
 
     return sequences
 
+
 def pad_ids(arrays, padding, max_length=-1):
     if max_length < 0:
         max_length = max(list(map(len, arrays)))
-    
-    arrays = [
-        array + [padding] * (max_length - len(array))
-        for array in arrays
-    ]
+
+    arrays = [array + [padding] * (max_length - len(array)) for array in arrays]
 
     return arrays
 
+
 def text_to_list(text):
-    return [t.strip().strip("'") for t in text.strip("]").strip("[").split(",")]
\ No newline at end of file
+    return [t.strip().strip("'") for t in text.strip("]").strip("[").split(",")]
