@@ -6,7 +6,7 @@ import spacy
 
 from kogito.core.knowledge import Knowledge, KnowledgeGraph
 from kogito.core.head import KnowledgeHead
-from kogito.core.relation import KG_RELATIONS
+from kogito.core.relation import PHYSICAL_RELATIONS, SOCIAL_RELATIONS, EVENT_RELATIONS
 from kogito.core.processors.head import (
     KnowledgeHeadExtractor,
     SentenceHeadExtractor,
@@ -18,12 +18,14 @@ from kogito.core.processors.relation import (
     GraphBasedRelationMatcher,
     KnowledgeRelationMatcher,
     SimpleRelationMatcher,
+    BaseRelationMatcher
 )
 from kogito.core.model import KnowledgeModel
 from kogito.core.linker import KnowledgeLinker
 from kogito.models.gpt3.zeroshot import GPT3Zeroshot
 from kogito.linkers.deberta import DebertaLinker
 
+
 class CommonsenseInference:
     """Main interface for commonsense inference"""
 
@@ -106,6 +108,12 @@ class CommonsenseInference:
                 It can be used to provide examples for GPT-3 inference. If omitted and GPT-3 model is used,
                 warning will be raised.
                 Defaults to None.
+            context (Optional[Union[List[str], str]], optional): Context text. Can be either given as a list of
+                                            sentences or as a string, in which case, it will be
+                                            split into sentences using spacy engine. Defaults to None.
+            threshold (float, optional): Relevance probability used for filtering. Defaults to 0.5.
+            linker (Optional[KnowledgeLinker], optional): Knowledge linker model used for linking to given context.
+                                                            Defaults to Deberta-based linker.
 
         Raises:
             ValueError: if relations argument is not of type list
@@ -118,10 +126,14 @@ class CommonsenseInference:
         head_texts = set()
         model_args = model_args or {}
 
+        if relations is not None and not isinstance(relations, list):
+            raise ValueError("Relation subset should be a list")
+
         if heads:
             for head in heads:
-                head_texts.add(head)
-                kg_heads.append(KnowledgeHead(text=head))
+                if isinstance(head, str) and head.strip():
+                    head_texts.add(head)
+                    kg_heads.append(KnowledgeHead(text=head))
 
         if extract_heads:
             if text:
@@ -139,6 +151,8 @@ class CommonsenseInference:
                 head_texts.add(text)
                 kg_heads.append(KnowledgeHead(text=text))
 
+        base_relation_matcher = BaseRelationMatcher("base-relation-matcher")
+
         if match_relations:
             print("Matching knowledge heads with relations...")
             for relation_proc in self._relation_processors.values():
@@ -149,16 +163,14 @@ class CommonsenseInference:
                         )
                     )
                 )
-        elif relations:
-            if not isinstance(relations, list):
-                raise ValueError("Relation subset should be a list")
-
-            head_relations = head_relations.union(
-                set(list(product(kg_heads, relations)))
-            )
         else:
+            print("Pairing knowledge heads with all relations...")
             head_relations = head_relations.union(
-                set(list(product(kg_heads, KG_RELATIONS)))
+                set(
+                    base_relation_matcher.match(
+                        kg_heads, relations, sample_graph=sample_graph
+                    )
+                )
             )
 
         kg_list = []
@@ -178,7 +190,7 @@ class CommonsenseInference:
                 )
 
         if dry_run or not model:
-            return input_graph
+            return input_graph.sort()
 
         print("Generating knowledge graph...")
         output_graph = model.generate(input_graph, **model_args)
@@ -191,6 +203,8 @@ class CommonsenseInference:
             print("Filtering knowledge graph based on the context...")
             output_graph = linker.filter(output_graph, context, threshold=threshold)
 
+        output_graph.sort()
+
         return output_graph
 
     def add_processor(
